wasm_mem_read

Function wasm_mem_read 

pub(crate) fn wasm_mem_read(
    env: &Env,
    store: &StoreMut<'_>,
    ptr: WasmPtr<u8>,
    ptr_len: u32,
) -> Result<Cursor<Vec<u8>>>
Create a mem slice of the WASM VM memory given a pointer and its length, and return a Cursor from which callers are able to read as a stream.